<nav role="navigation" class="navbar navbar-expand-md navbar-primary fixed-top">
  <div class="container"><a href="https://www.blender.org" title="Go to blender.org" class="navbar-brand navbar-logo-blender"></a>
    <button type="button" data-toggle="collapse" data-target="#navbar-collapse-menu" class="navbar-toggler"><span class="sr-only">Toggle navigation</span><span class="navbar-toggler-icon">
        <svg xmlns="http://www.w3.org/2000/svg" viewBox="-128 -128 2048 2048">
          <path d="M1664 1344v128q0 26-19 45t-45 19h-1408q-26 0-45-19t-19-45v-128q0-26 19-45t45-19h1408q26 0 45 19t19 45zm0-512v128q0 26-19 45t-45 19h-1408q-26 0-45-19t-19-45v-128q0-26 19-45t45-19h1408q26 0 45 19t19 45zm0-512v128q0 26-19 45t-45 19h-1408q-26 0-45-19t-19-45v-128q0-26 19-45t45-19h1408q26 0 45 19t19 45z"></path>
        </svg></span>
    </button>
    <div id="navbar-collapse-menu" class="collapse navbar-collapse">
      <ul class="navbar-nav ml-auto">
        <li><a href="https://www.blender.org/features/" title="Features" class="nav-link">Features</a>
        </li>
        <li><a href="https://www.blender.org/download/" title="Download" class="nav-link">Download</a>
        </li>
        <li><a href="https://www.blender.org/support/" title="Support" class="nav-link">Support</a>
        </li>
        <li><a href="https://www.blender.org/get-involved/" title="Get Involved" class="nav-link">Get Involved</a>
        </li>
        <li><a href="https://www.blender.org/about/" title="About" class="nav-link">About</a>
        </li>
        <li><a href="https://store.blender.org/" title="Store" class="nav-link">Store</a>
        </li>
        <li class="nav-cta"><a href="https://fund.blender.org/" title="Donate" class="nav-link"><i class="fa fa-heart"></i>Donate</a>
        </li>
      </ul>
    </div>
  </div>
</nav>