$font-body: -apple-system,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Oxygen,Ubuntu,Cantarell,"Open Sans",Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji" !default
$font-headings: $font-body !default

$font-size-base: .9rem !default
$font-size: $font-size-base !default
$font-size-small: .8rem !default
$font-size-smaller: .75rem !default
$font-size-smallest: .6rem !default
$font-size-normal: 1rem !default
$font-size-medium: 1.7rem !default
$font-size-large: 2.2rem !default
$font-size-larger: 2.6rem !default
$font-size-largest: 3rem !default

/* Bootstrap variables overrides. */
$enable-shadows: true

$border-width: 2px !default
$border-radius: .25rem !default
$btn-border-radius: .33rem !default

$font-family-sans-serif: $font-body !default
$font-family-base: $font-body !default
$lead-font-weight: normal !default
$display1-size: 6rem !default
$display2-size: 5rem !default
$display3-size: 4rem !default
$display4-size: 3rem !default

$input-box-shadow: none
$input-border-color: rgba(black, .1)
$input-border-width: 2px

$label-margin-bottom: .25rem

$form-group-margin-bottom: 1.5rem

$color-background: #f8f8f8 !default
$color-background-light: lighten($color-background, 5%) !default
$color-background-lighter: lighten($color-background, 10%) !default
$color-background-dark: darken($color-background, 5%) !default
$color-background-darker: darken($color-background, 10%) !default
$color-background-nav: hsl(hue($color-background), 20%, 25%)!default
$color-background-page: darken($color-background, 3%) !default

/* e.g. Links, the Bluish in borg */
$primary: #13b6fb !default
$color-primary: $primary !default
$color-primary-light: hsl(hue($color-primary), 30%, 90%) !default
$color-primary-dark: hsl(hue($color-primary), 80%, 30%) !default
$color-primary-accent:  hsl(hue($color-primary), 100%, 50%) !default

/* e.g. Active status of stuff, Orangish */
$color-secondary: #ff8844 !default
$color-secondary-light: hsl(hue($color-secondary), 30%, 90%) !default
$color-secondary-dark: hsl(hue($color-secondary), 80%, 40%) !default
$color-secondary-accent: hsl(hue($color-secondary), 100%, 50%) !default

$body-color: #4d4e53 !default
$color-text: $body-color !default
$color-text-dark: $color-text !default
$color-text-dark-primary: #646469 !default // rgba($color-text, .87)
$color-text-dark-secondary: #9E9FA2 !default // rgba($color-text, .54)
$color-text-dark-hint: #BBBBBD !default // rgba($color-text, .38)
$color-text-light: white !default
$color-text-light-primary: rgba($color-text-light, .87) !default
$color-text-light-secondary: rgba($color-text-light, .54) !default
$color-text-light-hint: rgba($color-text-light, .38) !default

$color-warning: #F3B935 !default
$color-info: #68B3C8 !default
$color-success: #48b936 !default
$color-danger: #EB5E28 !default

$container-width: 1170px !default

/* Dropdown */
$dropdown-border-color: $color-background
$dropdown-padding-y: 0
$dropdown-divider-margin-y: 0
$dropdown-item-padding-y: .7rem
$caret-spacing: .5rem

/* Mobile Stuff */
$container-max-widths: (sm: 820px, md: 940px, lg: 1080px, xl: 1140px) !default
$grid-breakpoints: (xs: 0,sm: 666px,md: 888px,lg: 1024px,xl: 1200px) !default

/* Just to do some math later */
/* Featured (our own jumbotron) */
$header-size-large: 480px !default

$navbar-padding-y: 0 !default
$nav-link-padding-x: 3rem !default
$nav-link-padding-y: 1rem !default

$alert-bg-level: -2 !default
$alert-color-level: 9 !default
$alert-border-radius: 0 !default
$alert-border-width: 0 !default
$alert-padding-x: 1.5rem !default

$nav-tabs-border-color: transparent !default
$nav-tabs-border-width: 2px !default
$nav-tabs-link-active-border-color: $primary !default
$nav-tabs-link-active-bg: transparent !default

$display4-weight: 400 !default

$popover-border-width: none

$border-radius-xl: .6rem

/* This map and properties are a copy of Bootstrap's from _variables.scss */
$spacer: 1rem !default
$spacers: () !default
$spacers: map-merge((0: 0,1: ($spacer * .25),2: ($spacer * .5),3: $spacer,4: ($spacer * 1.5),5: ($spacer * 3)), $spacers)

/* These are our own added sizes for spacers (my-n, px-n, etc). */
$spacers: map-merge($spacers, ("6": $spacer * 6))
$spacers: map-merge($spacers, ("7": $spacer * 12))
