.sidebar
	&-nav // sidebar-nav
		> ul
			list-style-type: none
			padding-left: 0

			> li
				background-color: white
				position: relative
				box-shadow: inset 0 -1px 0 rgba(black, .1)

				&:first-child
					border-top-left-radius: 3px
					border-top-right-radius: 3px

				&:last-child
					border-bottom-left-radius: 3px
					border-bottom-right-radius: 3px

				&:after
					display: none

				&.active
					box-shadow: inset 0 -1px 0 rgba(black, .1),  inset 3px 0 0 $color-primary
					border-bottom-left-radius: 0
					border-top-left-radius: 0

				&:hover
					a
						color: $color-primary

				a
					color: $color-text
					display: block
					padding: 10px 15px

					i
						padding-right: 10px
						position: relative
						top: 2px
