/*
 * Fonts
 * They must be copied into a 'fonts' folder one level
 * up from where the CSS is compiled.
 *
 * e.g. if CSS is in /webstatic/css/main.css
 * the 'fonts' folder in BWA should be copied over as /webstatic/fonts/
 */

// Override this variable on your local project before importing _font.sass
$font-path: '../fonts' !default
@import font_borg
